## CHANGELOG

### 0.0.1

Features:

  - First 16 Commands

### 0.0.2

Features:

  - Updated Readme

### 0.0.18

Features:

  - Updated CHANGELOG

### 1.0

Features:

  - No Changes, Made the ReadMe Beautiful to see

### 1.5

Features:

  - No Changes, Made the ReadMe Beautiful to see again bruh.